@@ -1,5 +1,5 @@
 package Date::Holidays::BY;
-our $VERSION = '1.2023.2'; # VERSION
+our $VERSION = '1.2024.0'; # VERSION
 
 =encoding utf8
 
@@ -43,6 +43,7 @@ use strict;
 use utf8;
 use base 'Exporter';
 use Carp;
+use List::Util;
 
 our @EXPORT_OK = qw(
     is_holiday
@@ -59,10 +60,8 @@ INACCURATE_TIMES_SINCE after this year dates of holidays and working day shift a
 
 =cut
 
-use List::Util;
-
 our $HOLIDAYS_VALID_SINCE = 2013; # TODO add all old
-our $INACCURATE_TIMES_SINCE = 2024;
+our $INACCURATE_TIMES_SINCE = 2025;
 
 =head2 $Date::Holidays::BY::strict
 
@@ -128,6 +127,7 @@ my %HOLIDAYS_SPECIAL = (
     2021 => [ qw( 0108 0510 0511 ) ],
     2022 => [ qw( 0307 0502 ) ],
     2023 => [ qw( 0424 0508 1106 ) ],
+    2024 => [ qw( 0513 1108 ) ],
 );
 
 my %BUSINESS_DAYS_ON_WEEKENDS = (
@@ -142,6 +142,7 @@ my %BUSINESS_DAYS_ON_WEEKENDS = (
     2021 => [ qw( 0116 0515 ) ],
     2022 => [ qw( 0312 0514 ) ],
     2023 => [ qw( 0429 0513 1111 ) ],
+    2024 => [ qw( 0518 1116 ) ],
 );
 
 my %SHORT_BUSINESS_DAYS = (
@@ -151,10 +152,7 @@ my %SHORT_BUSINESS_DAYS = (
     2017 => [ qw( 0106 0307 0429 0506 1104 ) ],
     2018 => [ qw( 0307 0508 1106 ) ],
     2019 => [ qw( 0307 0430 0506 0702 1106 1224 ) ],
-    2020 => [ qw( ) ],
-    2021 => [ qw( ) ],
-    2022 => [ qw( ) ],
-    2023 => [ qw( ) ],
+    # ... TODO
 );
 
 
@@ -162,6 +160,7 @@ my %SHORT_BUSINESS_DAYS = (
 sub _radonitsa_mmdd {
     my $year=$_[0];
     if ($year < 1583) {croak "Module has limitation in counting Easter outside the period 1583-7666";}
+    if ($year >= 2038 && "$]" < 5.012 && (eval{require Config; $Config::Config{ivsize}} < 8)) {croak "Require perl>=5.12.0 because 2038 problem";}
     require Date::Easter;
     my ($easter_month, $easter_day) = Date::Easter::orthodox_easter($year);
     my $radonitsa_month = $easter_month;
